@@ -131,7 +131,7 @@ class _HtmlToRtf(object):
 
     def handleElement(self, node, style):
         output = []
-        if node.tag in ["p", "li"]:
+        if node.tag in ["p", "li", 'strong', 'b', 'em', 'i', 'u']:
             txt = self.handleInlineText(node, [])
             if txt:
                 output.append(Paragraph(style, *txt))
@@ -233,7 +233,7 @@ class IdentificationReport(grok.View):
         return SessionManager.session.title
 
     def title(self, node, zodbnode):
-        if node.type != "risk" or node.identification in [u"n/a", u"yes"]:
+        if node.type != "risk" or node.identification in [u"n/a", u"yes", None]:
             return node.title
         if zodbnode.problem_description and \
                 zodbnode.problem_description.strip():
@@ -521,9 +521,9 @@ class ActionPlanReportDownload(grok.View):
         intro = t(_("plan_report_intro_1",
             default=u"By filling in the list of questions, you have "
                     u"completed a risk assessment. This assessment is used to "
-                    u"draw up an action plan.The progress of this action plan "
-                    u"must be discussed annually and a small report must "
-                    u"written on the progress. Certain subjects might have "
+                    u"draw up an action plan. The progress of this action "
+                    u"plan must be discussed annually and a small report must "
+                    u"be written on the progress. Certain subjects might have "
                     u"been completed and perhaps new subjects need to be "
                     u"added."))
         section.append(Paragraph(normal_style, intro))
@@ -837,6 +837,8 @@ class ActionPlanTimeline(grok.View):
             ]
 
     risk_columns = [
+            ('number',
+                _('label_risk_number', default=u'Risk number')),
             ('title',
                 _('report_timeline_risk_title', default=u'Risk')),
             ('priority',
@@ -858,6 +860,7 @@ class ActionPlanTimeline(grok.View):
         book = Workbook()
         sheet = book.worksheets[0]
         sheet.title = t(_('report_timeline_title', default=u'Timeline'))
+        survey = self.request.survey
 
         all_columns = self.plan_columns + self.risk_columns
         for (column, (key, title)) in enumerate(all_columns):
@@ -874,6 +877,11 @@ class ActionPlanTimeline(grok.View):
                 value = getattr(risk, key, None)
                 if key == 'priority':
                     value = self.priority_name(value)
+                elif key == 'title':
+                    zodb_node = survey.restrictedTraverse(risk.zodb_path.split('/'))
+                    if zodb_node.problem_description and \
+                            zodb_node.problem_description.strip():
+                        value = zodb_node.problem_description
                 if value is not None:
                     sheet.cell(row=row, column=column).value = value
                 column += 1
